package kotlin.reflect.jvm.internal;

import kotlin.Metadata;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.SourceDebugExtension;
import kotlin.reflect.jvm.internal.JvmFunctionSignature;
import kotlin.reflect.jvm.internal.JvmPropertySignature;
import kotlin.reflect.jvm.internal.KotlinReflectionInternalError;
import kotlin.reflect.jvm.internal.calls.ValueClassAwareCallerKt;
import kotlin.reflect.jvm.internal.impl.builtins.PrimitiveType;
import kotlin.reflect.jvm.internal.impl.builtins.StandardNames;
import kotlin.reflect.jvm.internal.impl.builtins.StandardNames.FqNames;
import kotlin.reflect.jvm.internal.impl.builtins.jvm.CloneableClassScope;
import kotlin.reflect.jvm.internal.impl.builtins.jvm.JavaToKotlinClassMap;
import kotlin.reflect.jvm.internal.impl.descriptors.CallableMemberDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.ClassDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.ClassifierDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.ConstructorDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.DeclarationDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.FunctionDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.PropertyDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.PropertyGetterDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.PropertySetterDescriptor;
import kotlin.reflect.jvm.internal.impl.descriptors.SourceElement;
import kotlin.reflect.jvm.internal.impl.descriptors.runtime.structure.ReflectClassUtilKt;
import kotlin.reflect.jvm.internal.impl.descriptors.runtime.structure.ReflectJavaClass;
import kotlin.reflect.jvm.internal.impl.descriptors.runtime.structure.ReflectJavaConstructor;
import kotlin.reflect.jvm.internal.impl.descriptors.runtime.structure.ReflectJavaField;
import kotlin.reflect.jvm.internal.impl.descriptors.runtime.structure.ReflectJavaMethod;
import kotlin.reflect.jvm.internal.impl.load.java.JvmAbi;
import kotlin.reflect.jvm.internal.impl.load.java.SpecialBuiltinMembers;
import kotlin.reflect.jvm.internal.impl.load.java.descriptors.JavaClassConstructorDescriptor;
import kotlin.reflect.jvm.internal.impl.load.java.descriptors.JavaMethodDescriptor;
import kotlin.reflect.jvm.internal.impl.load.java.descriptors.JavaPropertyDescriptor;
import kotlin.reflect.jvm.internal.impl.load.java.sources.JavaSourceElement;
import kotlin.reflect.jvm.internal.impl.load.java.structure.JavaElement;
import kotlin.reflect.jvm.internal.impl.load.kotlin.MethodSignatureMappingKt;
import kotlin.reflect.jvm.internal.impl.metadata.ProtoBuf.Constructor;
import kotlin.reflect.jvm.internal.impl.metadata.ProtoBuf.Function;
import kotlin.reflect.jvm.internal.impl.metadata.ProtoBuf.Property;
import kotlin.reflect.jvm.internal.impl.metadata.deserialization.ProtoBufUtilKt;
import kotlin.reflect.jvm.internal.impl.metadata.jvm.JvmProtoBuf;
import kotlin.reflect.jvm.internal.impl.metadata.jvm.deserialization.JvmProtoBufUtil;
import kotlin.reflect.jvm.internal.impl.metadata.jvm.deserialization.JvmMemberSignature.Method;
import kotlin.reflect.jvm.internal.impl.name.ClassId;
import kotlin.reflect.jvm.internal.impl.name.FqName;
import kotlin.reflect.jvm.internal.impl.protobuf.MessageLite;
import kotlin.reflect.jvm.internal.impl.protobuf.GeneratedMessageLite.ExtendableMessage;
import kotlin.reflect.jvm.internal.impl.resolve.DescriptorFactory;
import kotlin.reflect.jvm.internal.impl.resolve.DescriptorUtils;
import kotlin.reflect.jvm.internal.impl.resolve.InlineClassesUtilsKt;
import kotlin.reflect.jvm.internal.impl.resolve.descriptorUtil.DescriptorUtilsKt;
import kotlin.reflect.jvm.internal.impl.resolve.jvm.JvmPrimitiveType;
import kotlin.reflect.jvm.internal.impl.serialization.deserialization.descriptors.DeserializedCallableMemberDescriptor;
import kotlin.reflect.jvm.internal.impl.serialization.deserialization.descriptors.DeserializedMemberDescriptor;
import kotlin.reflect.jvm.internal.impl.serialization.deserialization.descriptors.DeserializedPropertyDescriptor;
import kotlin.text.StringsKt;
import org.jetbrains.annotations.NotNull;

@Metadata(
   mv = {2, 0, 0},
   k = 1,
   xi = 48,
   d1 = {"\u0000R\n\u0002\u0018\u0002\n\u0002\u0010\u0000\n\u0002\b\u0003\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u000b\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0010\u000e\n\u0002\u0018\u0002\n\u0002\b\u0002\n\u0002\u0018\u0002\n\u0000\n\u0002\u0018\u0002\n\u0002\b\u0003\bÀ\u0002\u0018\u00002\u00020\u0001B\t\b\u0002¢\u0006\u0004\b\u0002\u0010\u0003J\u000e\u0010\u0006\u001a\u00020\u00072\u0006\u0010\b\u001a\u00020\tJ\u000e\u0010\n\u001a\u00020\u000b2\u0006\u0010\f\u001a\u00020\rJ\u0010\u0010\u000e\u001a\u00020\u000f2\u0006\u0010\u0010\u001a\u00020\tH\u0002J\u0010\u0010\u0011\u001a\u00020\u00122\u0006\u0010\u0010\u001a\u00020\tH\u0002J\u0010\u0010\u0013\u001a\u00020\u00142\u0006\u0010\u0010\u001a\u00020\u0015H\u0002J\u0012\u0010\u0016\u001a\u00020\u00052\n\u0010\u0017\u001a\u0006\u0012\u0002\b\u00030\u0018R\u000e\u0010\u0004\u001a\u00020\u0005X\u0082\u0004¢\u0006\u0002\n\u0000R\u001e\u0010\u0019\u001a\u0004\u0018\u00010\u001a*\u0006\u0012\u0002\b\u00030\u00188BX\u0082\u0004¢\u0006\u0006\u001a\u0004\b\u001b\u0010\u001c¨\u0006\u001d"},
   d2 = {"Lkotlin/reflect/jvm/internal/RuntimeTypeMapper;", "", "<init>", "()V", "JAVA_LANG_VOID", "Lkotlin/reflect/jvm/internal/impl/name/ClassId;", "mapSignature", "Lkotlin/reflect/jvm/internal/JvmFunctionSignature;", "possiblySubstitutedFunction", "Lkotlin/reflect/jvm/internal/impl/descriptors/FunctionDescriptor;", "mapPropertySignature", "Lkotlin/reflect/jvm/internal/JvmPropertySignature;", "possiblyOverriddenProperty", "Lkotlin/reflect/jvm/internal/impl/descriptors/PropertyDescriptor;", "isKnownBuiltInFunction", "", "descriptor", "mapJvmFunctionSignature", "Lkotlin/reflect/jvm/internal/JvmFunctionSignature$KotlinFunction;", "mapName", "", "Lkotlin/reflect/jvm/internal/impl/descriptors/CallableMemberDescriptor;", "mapJvmClassToKotlinClassId", "klass", "Ljava/lang/Class;", "primitiveType", "Lkotlin/reflect/jvm/internal/impl/builtins/PrimitiveType;", "getPrimitiveType", "(Ljava/lang/Class;)Lorg/jetbrains/kotlin/builtins/PrimitiveType;", "kotlin-reflection"}
)
@SourceDebugExtension({"SMAP\nRuntimeTypeMapper.kt\nKotlin\n*S Kotlin\n*F\n+ 1 RuntimeTypeMapper.kt\nkotlin/reflect/jvm/internal/RuntimeTypeMapper\n+ 2 fake.kt\nkotlin/jvm/internal/FakeKt\n*L\n1#1,302:1\n1#2:303\n*E\n"})
public final class RuntimeTypeMapper {

   @NotNull
   public static final RuntimeTypeMapper INSTANCE = new RuntimeTypeMapper();
   @NotNull
   private static final ClassId JAVA_LANG_VOID = ClassId.Companion.topLevel(new FqName("java.lang.Void"));


   @NotNull
   public final JvmFunctionSignature mapSignature(@NotNull FunctionDescriptor possiblySubstitutedFunction) {
      Intrinsics.checkNotNullParameter(possiblySubstitutedFunction, "possiblySubstitutedFunction");
      FunctionDescriptor var10000 = ((FunctionDescriptor)DescriptorUtils.unwrapFakeOverride((CallableMemberDescriptor)possiblySubstitutedFunction)).getOriginal();
      Intrinsics.checkNotNullExpressionValue(var10000, "getOriginal(...)");
      FunctionDescriptor function = var10000;
      JvmFunctionSignature var19;
      if(function instanceof DeserializedCallableMemberDescriptor) {
         MessageLite element2 = ((DeserializedMemberDescriptor)function).getProto();
         Method var5;
         boolean $i$a$-let-RuntimeTypeMapper$mapSignature$21;
         if(element2 instanceof Function) {
            var5 = JvmProtoBufUtil.INSTANCE.getJvmMethodSignature((Function)element2, ((DeserializedMemberDescriptor)function).getNameResolver(), ((DeserializedMemberDescriptor)function).getTypeTable());
            if(var5 != null) {
               $i$a$-let-RuntimeTypeMapper$mapSignature$21 = false;
               return (JvmFunctionSignature)(new JvmFunctionSignature.KotlinFunction(var5));
            }
         }

         if(element2 instanceof Constructor) {
            var5 = JvmProtoBufUtil.INSTANCE.getJvmConstructorSignature((Constructor)element2, ((DeserializedMemberDescriptor)function).getNameResolver(), ((DeserializedMemberDescriptor)function).getTypeTable());
            if(var5 != null) {
               $i$a$-let-RuntimeTypeMapper$mapSignature$21 = false;
               DeclarationDescriptor var22 = possiblySubstitutedFunction.getContainingDeclaration();
               Intrinsics.checkNotNullExpressionValue(var22, "getContainingDeclaration(...)");
               if(InlineClassesUtilsKt.isInlineClass(var22)) {
                  var19 = (JvmFunctionSignature)(new JvmFunctionSignature.KotlinFunction(var5));
               } else {
                  var22 = possiblySubstitutedFunction.getContainingDeclaration();
                  Intrinsics.checkNotNullExpressionValue(var22, "getContainingDeclaration(...)");
                  if(InlineClassesUtilsKt.isMultiFieldValueClass(var22)) {
                     boolean $i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$2;
                     String $i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$21;
                     Method var23;
                     if(((ConstructorDescriptor)possiblySubstitutedFunction).isPrimary()) {
                        if(!Intrinsics.areEqual(var5.getName(), "constructor-impl") || !StringsKt.endsWith$default(var5.getDesc(), ")V", false, 2, (Object)null)) {
                           $i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$2 = false;
                           $i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$21 = "Invalid signature: " + var5;
                           throw new IllegalArgumentException($i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$21.toString());
                        }

                        var23 = var5;
                     } else {
                        if(!Intrinsics.areEqual(var5.getName(), "constructor-impl")) {
                           $i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$2 = false;
                           $i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$21 = "Invalid signature: " + var5;
                           throw new IllegalArgumentException($i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$21.toString());
                        }

                        ClassDescriptor var24 = ((ConstructorDescriptor)possiblySubstitutedFunction).getConstructedClass();
                        Intrinsics.checkNotNullExpressionValue(var24, "getConstructedClass(...)");
                        String constructedClass = ValueClassAwareCallerKt.toJvmDescriptor((ClassifierDescriptor)var24);
                        if(StringsKt.endsWith$default(var5.getDesc(), ")V", false, 2, (Object)null)) {
                           var23 = Method.copy$default(var5, (String)null, StringsKt.removeSuffix(var5.getDesc(), (CharSequence)"V") + constructedClass, 1, (Object)null);
                        } else {
                           if(!StringsKt.endsWith$default(var5.getDesc(), constructedClass, false, 2, (Object)null)) {
                              boolean $i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$3 = false;
                              String $i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$31 = "Invalid signature: " + var5;
                              throw new IllegalArgumentException($i$a$-require-RuntimeTypeMapper$mapSignature$2$realSignature$31.toString());
                           }

                           var23 = var5;
                        }
                     }

                     Method realSignature = var23;
                     var19 = (JvmFunctionSignature)(new JvmFunctionSignature.KotlinFunction(realSignature));
                  } else {
                     var19 = (JvmFunctionSignature)(new JvmFunctionSignature.KotlinConstructor(var5));
                  }
               }

               return var19;
            }
         }

         return (JvmFunctionSignature)this.mapJvmFunctionSignature(function);
      } else if(function instanceof JavaMethodDescriptor) {
         SourceElement $i$a$-let-RuntimeTypeMapper$mapSignature$2 = ((JavaMethodDescriptor)function).getSource();
         JavaElement var15 = ($i$a$-let-RuntimeTypeMapper$mapSignature$2 instanceof JavaSourceElement?(JavaSourceElement)$i$a$-let-RuntimeTypeMapper$mapSignature$2:null) != null?($i$a$-let-RuntimeTypeMapper$mapSignature$2 instanceof JavaSourceElement?(JavaSourceElement)$i$a$-let-RuntimeTypeMapper$mapSignature$2:null).getJavaElement():null;
         ReflectJavaMethod var20 = var15 instanceof ReflectJavaMethod?(ReflectJavaMethod)var15:null;
         if((var15 instanceof ReflectJavaMethod?(ReflectJavaMethod)var15:null) != null) {
            java.lang.reflect.Method var21 = var20.getMember();
            if(var21 != null) {
               java.lang.reflect.Method element1 = var21;
               return (JvmFunctionSignature)(new JvmFunctionSignature.JavaMethod(element1));
            }
         }

         throw new KotlinReflectionInternalError("Incorrect resolution sequence for Java method " + function);
      } else if(function instanceof JavaClassConstructorDescriptor) {
         SourceElement var6 = ((JavaClassConstructorDescriptor)function).getSource();
         JavaElement element = (var6 instanceof JavaSourceElement?(JavaSourceElement)var6:null) != null?(var6 instanceof JavaSourceElement?(JavaSourceElement)var6:null).getJavaElement():null;
         if(element instanceof ReflectJavaConstructor) {
            var19 = (JvmFunctionSignature)(new JvmFunctionSignature.JavaConstructor(((ReflectJavaConstructor)element).getMember()));
         } else {
            if(!(element instanceof ReflectJavaClass) || !((ReflectJavaClass)element).isAnnotationType()) {
               throw new KotlinReflectionInternalError("Incorrect resolution sequence for Java constructor " + function + " (" + element + ')');
            }

            var19 = (JvmFunctionSignature)(new JvmFunctionSignature.FakeJavaAnnotationConstructor(((ReflectJavaClass)element).getElement()));
         }

         return var19;
      } else if(this.isKnownBuiltInFunction(function)) {
         return (JvmFunctionSignature)this.mapJvmFunctionSignature(function);
      } else {
         throw new KotlinReflectionInternalError("Unknown origin of " + function + " (" + function.getClass() + ')');
      }
   }

   @NotNull
   public final JvmPropertySignature mapPropertySignature(@NotNull PropertyDescriptor possiblyOverriddenProperty) {
      Intrinsics.checkNotNullParameter(possiblyOverriddenProperty, "possiblyOverriddenProperty");
      PropertyDescriptor var10000 = ((PropertyDescriptor)DescriptorUtils.unwrapFakeOverride((CallableMemberDescriptor)possiblyOverriddenProperty)).getOriginal();
      Intrinsics.checkNotNullExpressionValue(var10000, "getOriginal(...)");
      PropertyDescriptor property = var10000;
      if(property instanceof DeserializedPropertyDescriptor) {
         Property p0 = ((DeserializedPropertyDescriptor)property).getProto();
         ExtendableMessage var17 = (ExtendableMessage)p0;
         Intrinsics.checkNotNullExpressionValue(JvmProtoBuf.propertySignature, "propertySignature");
         kotlin.reflect.jvm.internal.impl.metadata.jvm.JvmProtoBuf.JvmPropertySignature p01 = (kotlin.reflect.jvm.internal.impl.metadata.jvm.JvmProtoBuf.JvmPropertySignature)ProtoBufUtilKt.getExtensionOrNull(var17, JvmProtoBuf.propertySignature);
         if(p01 != null) {
            return (JvmPropertySignature)(new JvmPropertySignature.KotlinProperty(property, p0, p01, ((DeserializedPropertyDescriptor)property).getNameResolver(), ((DeserializedPropertyDescriptor)property).getTypeTable()));
         }
      } else if(property instanceof JavaPropertyDescriptor) {
         SourceElement $i$a$-let-RuntimeTypeMapper$mapPropertySignature$21 = ((JavaPropertyDescriptor)property).getSource();
         JavaElement p03 = ($i$a$-let-RuntimeTypeMapper$mapPropertySignature$21 instanceof JavaSourceElement?(JavaSourceElement)$i$a$-let-RuntimeTypeMapper$mapPropertySignature$21:null) != null?($i$a$-let-RuntimeTypeMapper$mapPropertySignature$21 instanceof JavaSourceElement?(JavaSourceElement)$i$a$-let-RuntimeTypeMapper$mapPropertySignature$21:null).getJavaElement():null;
         JvmPropertySignature var21;
         if(p03 instanceof ReflectJavaField) {
            var21 = (JvmPropertySignature)(new JvmPropertySignature.JavaField(((ReflectJavaField)p03).getMember()));
         } else {
            if(!(p03 instanceof ReflectJavaMethod)) {
               throw new KotlinReflectionInternalError("Incorrect resolution sequence for Java field " + property + " (source = " + p03 + ')');
            }

            java.lang.reflect.Method var10002 = ((ReflectJavaMethod)p03).getMember();
            PropertySetterDescriptor var10003 = ((JavaPropertyDescriptor)property).getSetter();
            SourceElement var7 = var10003 != null?var10003.getSource():null;
            JavaElement $i$a$-let-RuntimeTypeMapper$mapPropertySignature$22 = (var7 instanceof JavaSourceElement?(JavaSourceElement)var7:null) != null?(var7 instanceof JavaSourceElement?(JavaSourceElement)var7:null).getJavaElement():null;
            var21 = (JvmPropertySignature)(new JvmPropertySignature.JavaMethodProperty(var10002, ($i$a$-let-RuntimeTypeMapper$mapPropertySignature$22 instanceof ReflectJavaMethod?(ReflectJavaMethod)$i$a$-let-RuntimeTypeMapper$mapPropertySignature$22:null) != null?($i$a$-let-RuntimeTypeMapper$mapPropertySignature$22 instanceof ReflectJavaMethod?(ReflectJavaMethod)$i$a$-let-RuntimeTypeMapper$mapPropertySignature$22:null).getMember():null));
         }

         return var21;
      }

      PropertyGetterDescriptor var18 = property.getGetter();
      Intrinsics.checkNotNull(var18);
      FunctionDescriptor p02 = (FunctionDescriptor)var18;
      boolean p04 = false;
      JvmFunctionSignature.KotlinFunction var19 = this.mapJvmFunctionSignature(p02);
      PropertySetterDescriptor var10001 = property.getSetter();
      JvmFunctionSignature.KotlinFunction var20;
      if(var10001 != null) {
         FunctionDescriptor p05 = (FunctionDescriptor)var10001;
         JvmFunctionSignature.KotlinFunction var8 = var19;
         boolean $i$a$-let-RuntimeTypeMapper$mapPropertySignature$2 = false;
         var20 = this.mapJvmFunctionSignature(p05);
         var19 = var8;
      } else {
         var20 = null;
      }

      JvmFunctionSignature.KotlinFunction var9 = var20;
      JvmFunctionSignature.KotlinFunction var10 = var19;
      return (JvmPropertySignature)(new JvmPropertySignature.MappedKotlinProperty(var10, var9));
   }

   private final boolean isKnownBuiltInFunction(FunctionDescriptor descriptor) {
      return !DescriptorFactory.isEnumValueOfMethod(descriptor) && !DescriptorFactory.isEnumValuesMethod(descriptor)?Intrinsics.areEqual(descriptor.getName(), CloneableClassScope.Companion.getCLONE_NAME()) && descriptor.getValueParameters().isEmpty():true;
   }

   private final JvmFunctionSignature.KotlinFunction mapJvmFunctionSignature(FunctionDescriptor descriptor) {
      return new JvmFunctionSignature.KotlinFunction(new Method(this.mapName((CallableMemberDescriptor)descriptor), MethodSignatureMappingKt.computeJvmDescriptor$default(descriptor, false, false, 1, (Object)null)));
   }

   private final String mapName(CallableMemberDescriptor descriptor) {
      String var10000 = SpecialBuiltinMembers.getJvmMethodNameIfSpecial(descriptor);
      if(var10000 == null) {
         if(descriptor instanceof PropertyGetterDescriptor) {
            var10000 = DescriptorUtilsKt.getPropertyIfAccessor(descriptor).getName().asString();
            Intrinsics.checkNotNullExpressionValue(var10000, "asString(...)");
            var10000 = JvmAbi.getterName(var10000);
         } else if(descriptor instanceof PropertySetterDescriptor) {
            var10000 = DescriptorUtilsKt.getPropertyIfAccessor(descriptor).getName().asString();
            Intrinsics.checkNotNullExpressionValue(var10000, "asString(...)");
            var10000 = JvmAbi.setterName(var10000);
         } else {
            var10000 = descriptor.getName().asString();
            Intrinsics.checkNotNullExpressionValue(var10000, "asString(...)");
         }
      }

      return var10000;
   }

   @NotNull
   public final ClassId mapJvmClassToKotlinClassId(@NotNull Class klass) {
      Intrinsics.checkNotNullParameter(klass, "klass");
      PrimitiveType classId;
      boolean it;
      if(klass.isArray()) {
         Class var10001 = klass.getComponentType();
         Intrinsics.checkNotNullExpressionValue(var10001, "getComponentType(...)");
         classId = this.getPrimitiveType(var10001);
         if(classId != null) {
            it = false;
            return new ClassId(StandardNames.BUILT_INS_PACKAGE_FQ_NAME, classId.getArrayTypeName());
         } else {
            FqName var8 = FqNames.array.toSafe();
            Intrinsics.checkNotNullExpressionValue(var8, "toSafe(...)");
            return ClassId.Companion.topLevel(var8);
         }
      } else if(Intrinsics.areEqual(klass, Void.TYPE)) {
         return JAVA_LANG_VOID;
      } else {
         classId = this.getPrimitiveType(klass);
         if(classId != null) {
            it = false;
            return new ClassId(StandardNames.BUILT_INS_PACKAGE_FQ_NAME, classId.getTypeName());
         } else {
            ClassId classId1 = ReflectClassUtilKt.getClassId(klass);
            if(!classId1.isLocal()) {
               ClassId var3 = JavaToKotlinClassMap.INSTANCE.mapJavaToKotlin(classId1.asSingleFqName());
               if(var3 != null) {
                  boolean $i$a$-let-RuntimeTypeMapper$mapJvmClassToKotlinClassId$3 = false;
                  return var3;
               }
            }

            return classId1;
         }
      }
   }

   private final PrimitiveType getPrimitiveType(Class $this$primitiveType) {
      return $this$primitiveType.isPrimitive()?JvmPrimitiveType.get($this$primitiveType.getSimpleName()).getPrimitiveType():null;
   }

}
